package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsBaseShutType;

/**
 * 停机类型信息Service接口
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
public interface IDmsBaseShutTypeService 
{
    /**
     * 查询停机类型信息
     * 
     * @param shutTypeId 停机类型信息主键
     * @return 停机类型信息
     */
    public DmsBaseShutType selectDmsBaseShutTypeByShutTypeId(Long shutTypeId);

    /**
     * 查询停机类型信息列表
     * 
     * @param dmsBaseShutType 停机类型信息
     * @return 停机类型信息集合
     */
    public List<DmsBaseShutType> selectDmsBaseShutTypeList(DmsBaseShutType dmsBaseShutType);

    /**
     * 新增停机类型信息
     * 
     * @param dmsBaseShutType 停机类型信息
     * @return 结果
     */
    public int insertDmsBaseShutType(DmsBaseShutType dmsBaseShutType);

    /**
     * 修改停机类型信息
     * 
     * @param dmsBaseShutType 停机类型信息
     * @return 结果
     */
    public int updateDmsBaseShutType(DmsBaseShutType dmsBaseShutType);

    /**
     * 批量删除停机类型信息
     * 
     * @param shutTypeIds 需要删除的停机类型信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseShutTypeByShutTypeIds(Long[] shutTypeIds);

    /**
     * 删除停机类型信息信息
     * 
     * @param shutTypeId 停机类型信息主键
     * @return 结果
     */
    public int deleteDmsBaseShutTypeByShutTypeId(Long shutTypeId);
}
