package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseShutType;
import com.hw.dms.service.IDmsBaseShutTypeService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 停机类型信息Controller
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/shutType")
public class DmsBaseShutTypeController extends BaseController
{
    @Autowired
    private IDmsBaseShutTypeService dmsBaseShutTypeService;

    /**
     * 查询停机类型信息列表
     */
    @RequiresPermissions("dms:shutType:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseShutType dmsBaseShutType)
    {
        startPage();
        List<DmsBaseShutType> list = dmsBaseShutTypeService.selectDmsBaseShutTypeList(dmsBaseShutType);
        return getDataTable(list);
    }

    /**
     * 导出停机类型信息列表
     */
    @RequiresPermissions("dms:shutType:export")
    @Log(title = "停机类型信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseShutType dmsBaseShutType)
    {
        List<DmsBaseShutType> list = dmsBaseShutTypeService.selectDmsBaseShutTypeList(dmsBaseShutType);
        ExcelUtil<DmsBaseShutType> util = new ExcelUtil<DmsBaseShutType>(DmsBaseShutType.class);
        util.exportExcel(response, list, "停机类型信息数据");
    }

    /**
     * 获取停机类型信息详细信息
     */
    @RequiresPermissions("dms:shutType:query")
    @GetMapping(value = "/{shutTypeId}")
    public AjaxResult getInfo(@PathVariable("shutTypeId") Long shutTypeId)
    {
        return success(dmsBaseShutTypeService.selectDmsBaseShutTypeByShutTypeId(shutTypeId));
    }

    /**
     * 新增停机类型信息
     */
    @RequiresPermissions("dms:shutType:add")
    @Log(title = "停机类型信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseShutType dmsBaseShutType)
    {
        return toAjax(dmsBaseShutTypeService.insertDmsBaseShutType(dmsBaseShutType));
    }

    /**
     * 修改停机类型信息
     */
    @RequiresPermissions("dms:shutType:edit")
    @Log(title = "停机类型信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseShutType dmsBaseShutType)
    {
        return toAjax(dmsBaseShutTypeService.updateDmsBaseShutType(dmsBaseShutType));
    }

    /**
     * 删除停机类型信息
     */
    @RequiresPermissions("dms:shutType:remove")
    @Log(title = "停机类型信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{shutTypeIds}")
    public AjaxResult remove(@PathVariable Long[] shutTypeIds)
    {
        return toAjax(dmsBaseShutTypeService.deleteDmsBaseShutTypeByShutTypeIds(shutTypeIds));
    }
}
